colour.models.dataset.prophoto_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.prophoto_rgb Module

## ProPhoto RGB Colourspace

Defines the ProPhoto RGB colourspace:

- `PROPHOTO_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.color.org/ROMMRGB.pdf (Last accessed 24 February 2014)

`colour.models.dataset.prophoto_rgb.` `PROPHOTO_RGB_PRIMARIES` = array([[ 7.34700000e-01, 2.65300000e-01], [ 1.59600000e-01, 8.40400000e-01], [ 3.66000000e-02, 1.00000000e-04]])

  ProPhoto RGB colourspace primaries.

  PROPHOTO_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.prophoto_rgb.` `PROPHOTO_RGB_WHITEPOINT` = (0.34567, 0.3585)

  ProPhoto RGB colourspace whitepoint.

  PROPHOTO_RGB_WHITEPOINT : tuple

`colour.models.dataset.prophoto_rgb.` `PROPHOTO_RGB_TO_XYZ_MATRIX` = array([[ 7.97667235e-01, 1.35192231e-01, 3.13525290e-02], [ 2.88037454e-01, 7.11876883e-01, 8.56626476e-05], [ 0.00000000e+00, 0.00000000e+00, 8.25188285e-01]])

  ProPhoto RGB colourspace to CIE XYZ colourspace matrix.

  PROPHOTO_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.prophoto_rgb.` `XYZ_TO_PROPHOTO_RGB_MATRIX` = array([[ 1.34595631, -0.25560998, -0.05111226], [-0.54459674, 1.50816142, 0.02053506], [ 0. , 0. , 1.21184464]])

  CIE XYZ colourspace to ProPhoto RGB colourspace matrix.

  XYZ_TO_PROPHOTO_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.prophoto_rgb.` `PROPHOTO_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to ProPhoto RGB colourspace.

  PROPHOTO_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.prophoto_rgb.` `PROPHOTO_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from ProPhoto RGB colourspace to linear.

  PROPHOTO_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.prophoto_rgb.` `PROPHOTO_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24bd0>

  ProPhoto RGB colourspace.

  PROPHOTO_RGB_COLOURSPACE : RGB_Colourspace